pub struct NullSink;Expand description
A no-op sink that discards all events.
Used by background sub-agents that don’t have a live channel to
the user. #1022 B9: superseded for bg-agent use by
BufferingSink, which captures a narrative trace so the user
can see what the bg agent did at result-injection time. NullSink
is still useful for tests and for any future fully-detached
execution path.