append

Function append 

pub fn append(project_root: &Path, entry: &str) -> Result<()>
Write an entry to the project’s memory file.

If the entry starts with a ## Heading, and a section with that heading already exists in the file, the existing section is replaced (updated in place). Otherwise the entry is appended.

Always targets the active memory file (or MEMORY.md if none exists).