pub struct DiffHunk {
pub old_start: usize,
pub old_count: usize,
pub new_start: usize,
pub new_count: usize,
pub lines: Vec<DiffLine>,
}Expand description
A single hunk in a unified diff.
Fields
old_start: usize1-based starting line in the old file.
old_count: usizeNumber of lines from the old file in this hunk.
new_start: usize1-based starting line in the new file.
new_count: usizeNumber of lines from the new file in this hunk.
lines: Vec<DiffLine>The lines in this hunk (context + insertions + deletions).